@@ -16,7 +16,7 @@ import java.awt.Graphics2D;
 
 import org.scilab.forge.scirenderer.Canvas;
 import org.scilab.forge.scirenderer.Drawer;
-import org.scilab.forge.scirenderer.depthtest.DepthTestManager;
+import org.scilab.forge.scirenderer.DrawingTools;
 import org.scilab.forge.scirenderer.implementation.g2d.buffers.G2DBuffersManager;
 import org.scilab.forge.scirenderer.implementation.g2d.motor.Motor3D;
 import org.scilab.forge.scirenderer.implementation.g2d.renderer.G2DRendererManager;
@@ -40,17 +40,6 @@ public final class G2DCanvas implements Canvas {
     private final Motor3D motor;
     private final Dimension dimension;
 
-    private static final DepthTestManager DEPTHTESTMANAGER = new DepthTestManager() {
-	    
-	    @Override
-	    public boolean isAutoClearDepthBufferEnable() {
-		return true;
-	    }
-	    
-	    @Override
-	    public void setAutoClearDepthBufferEnable(boolean status) { }
-	};
-
     private static final PickingManager PICKINGMANAGER = new PickingManager() {
 	    
 	    @Override
@@ -77,6 +66,10 @@ public final class G2DCanvas implements Canvas {
         textureManager = new G2DTextureManager(this);
     }
 
+    public DrawingTools getDrawingTools() {
+	return drawingTools;
+    }
+
     // Implementation of getter & setter from Canvas.
 
     @Override
@@ -99,11 +92,6 @@ public final class G2DCanvas implements Canvas {
         return buffersManager;
     }
 
-    @Override
-    public DepthTestManager getDepthTestManager() {
-	return DEPTHTESTMANAGER;
-    }
-
     @Override
     public PickingManager getPickingManager() {
     	return PICKINGMANAGER;
@@ -131,7 +119,11 @@ public final class G2DCanvas implements Canvas {
 
     @Override
     public void redraw() {
-	draw();
+	    draw();
+    }
+
+    @Override
+    public void waitImage() {
     }
 
     // G2DCanvas specific getter.
